@@ -23,7 +23,7 @@
 #include <Lum/Model/Boolean.h>
 #include <Lum/Model/Number.h>
 
-extern Lum::Model::SizeTRef unitMode;
+extern Lum::Model::ULongRef   unitMode;
 extern Lum::Model::BooleanRef prohibitScreenBlanking;
 extern Lum::Model::BooleanRef compassShowCourseDirection;
 extern Lum::Model::BooleanRef compassShowRawGPSDirection;
