@@ -22,7 +22,7 @@
 
 #include <string>
 
-extern std::wstring DoubleToString(double value);
+extern std::wstring DoubleToString(double value, int precision = 2);
 
 extern std::wstring GetSpeedNoDataUnit();
 extern std::wstring GetSpeedAsString(double metric);
@@ -32,4 +32,15 @@ extern std::wstring GetSpeedAndUnitAsString(double metric, double dev);
 
 extern std::wstring GetMetricAndUnitAsString(double metric);
 extern std::wstring GetMetricAndUnitAsString(double metric, double dev);
+
+extern std::wstring GetAngleAsDegreeMinuteSecondString(double angle360,
+                                          const wchar_t *negativePrefix = L"-",
+                                          const wchar_t *positivePrefix = L"+",
+                                          int secondPrecision = 2);
+
+extern double CalculateWeightedDirection(double oldAngle,
+                                         double newAngle,
+                                         double newWeight0to1,
+                                         double fullCircleAngle = 360);
+
 #endif
